@@ -174,14 +174,18 @@ print.summary.p2canon <- function(x, ...)
               for (k in Qfitlab)
               { 
                 Qjik <- Q2[[k]] %*% Q1[[i]] %*% Q2[[j]]
-                if(!is.allzero(Qjik))
+                if (!is.allzero(Qjik))
                 {
+                  Qij <- proj2.combine(Q1[[i]], Q2[[j]])$Qconf
+                  Qik <- proj2.combine(Q1[[i]], Q2[[k]])$Qconf
+                  Qikj <- proj2.combine(Qik, Qij)
                   warning(paste(j,"and",k,"are partially aliased in",i, sep=" "))
-                  eff.crit <- efficiency.criteria(adj.Q1Q2$efficiencies)
-                  names(eff.crit) <- criteria
+#                  eff.crit <- efficiency.criteria(adj.Q1Q2$efficiencies)
+                  eff.crit <- efficiency.criteria(Qikj$efficiencies)
+#                  names(eff.crit) <- criteria
                   aliasing <- rbind(aliasing, 
                                     data.frame(c(list(Source = j, 
-                                                      df = degfree(adj.Q1Q2$Qconf),
+                                                      df = degfree(Qikj$Qconf), #degfree(adj.Q1Q2$Qconf),
                                                       Alias = k,
                                                       In = i),
                                                  eff.crit[criteria]), 
@@ -215,12 +219,14 @@ print.summary.p2canon <- function(x, ...)
           } else
           {
             warning(paste(j,"is aliased with previous terms in",i, sep=" "))
+#            eff.crit <- rep(1, length(criteria))
             eff.crit <- rep(0, length(criteria))
             names(eff.crit) <- criteria
             aliasing <- rbind(aliasing, 
                               data.frame(c(list(Source = j, 
-                                                df = 0,
-                                                Alias = "unknown",
+                                                df =  0, #degfree(Q2[[j]]), 
+#                                                Alias = "unknown",
+                                                Alias = "## Aliased",
                                                 In = i),
                                           eff.crit), 
                                          stringsAsFactors = FALSE))
